InstrumentationScope

Struct InstrumentationScope 

pub struct InstrumentationScope {
    pub name: String,
    pub version: String,
    pub attributes: Vec<KeyValue>,
    pub dropped_attributes_count: u32,
}
InstrumentationScope is a message representing the instrumentation scope information such as the fully qualified name and version.

Fields

name: String

A name denoting the Instrumentation scope. An empty instrumentation scope name means the name is unknown.

version: String

Defines the version of the instrumentation scope. An empty instrumentation scope version means the version is unknown.

attributes: Vec<KeyValue>

Additional attributes that describe the scope. [Optional]. Attribute keys MUST be unique (it is not allowed to have more than one attribute with the same key). The behavior of software that receives duplicated keys can be unpredictable.

dropped_attributes_count: u32

The number of attributes that were discarded. Attributes can be discarded because their keys are too long or because there are too many attributes. If this value is 0, then no attributes were dropped.