KeyValueList

Struct KeyValueList 

pub struct KeyValueList {
    pub values: Vec<KeyValue>,
}
KeyValueList is a list of KeyValue messages. We need KeyValueList as a message since oneof in AnyValue does not allow repeated fields. Everywhere else where we need a list of KeyValue messages (e.g. in Span) we use repeated KeyValue directly to avoid unnecessary extra wrapping (which slows down the protocol). The 2 approaches are semantically equivalent.

Fields

values: Vec<KeyValue>

A collection of key/value pairs of key-value pairs. The list may be empty (may contain 0 elements).

The keys MUST be unique (it is not allowed to have more than one value with the same key). The behavior of software that receives duplicated keys can be unpredictable.